@@ -83,7 +83,7 @@ class Loop3DView(pv.Plotter):
         return model
 
     def _get_vector_scale(self, scale: Optional[Union[float, int]]) -> float:
-        autoscale = 0.0
+        autoscale = 1.0
         if self.model is not None:
             # automatically scale vector data to be 5% of the bounding box length
             autoscale = self.model.bounding_box.length.max() * 0.05
@@ -109,7 +109,7 @@ class Loop3DView(pv.Plotter):
         vmin: Optional[float] = None,
         vmax: Optional[float] = None,
         pyvista_kwargs: dict = {},
-        scalar_bar: bool = False,
+        show_scalar_bar: bool = False,
         slicer: bool = False,
         name: Optional[str] = None,
         bounding_box: Optional[BoundingBox] = None,
@@ -140,7 +140,7 @@ class Loop3DView(pv.Plotter):
             name of the object, by default None
         slicer : bool, optional
             If an interactive plane slicing tool should be added, by default False
-        scalar_bar : bool, optional
+        show_scalar_bar : bool, optional
             Whether to show the scalar bar, by default False
         """
 
@@ -192,7 +192,7 @@ class Loop3DView(pv.Plotter):
 
         except ValueError:
             logger.warning("No surfaces to plot")
-        if paint_with is not None and not scalar_bar:
+        if paint_with is not None and not show_scalar_bar:
             self.remove_scalar_bar('values')
         return actor
 
@@ -204,9 +204,10 @@ class Loop3DView(pv.Plotter):
         vmax: Optional[float] = None,
         opacity: Optional[float] = None,
         pyvista_kwargs: dict = {},
-        scalar_bar: bool = False,
+        show_scalar_bar: bool = False,
         slicer: bool = False,
         name: Optional[str] = None,
+        bounding_box: Optional[BoundingBox] = None,
     ):
         """Plot a volume with the scalar field as the property
         calls feature.scalar_field() to get the scalar field and
@@ -226,7 +227,7 @@ class Loop3DView(pv.Plotter):
             opacity of the object, by default None
         pyvista_kwargs : dict, optional
             additional kwargs sent to add_mesh, by default {}
-        scalar_bar : bool, optional
+        show_scalar_bar : bool, optional
             whether to show or hide the scalar bar, by default False
         slicer : bool, optional
             whether to plot using a plane slicer widget, by default False
@@ -243,7 +244,7 @@ class Loop3DView(pv.Plotter):
             name = geological_feature.name + '_scalar_field'
         name = self.increment_name(name)  # , 'scalar_field')
 
-        volume = geological_feature.scalar_field().vtk()
+        volume = geological_feature.scalar_field(bounding_box=bounding_box).vtk()
         if vmin is not None:
             pyvista_kwargs["clim"][0] = vmin
         if vmax is not None:
@@ -254,7 +255,7 @@ class Loop3DView(pv.Plotter):
             )
         else:
             actor = self.add_mesh(volume, cmap=cmap, opacity=opacity, name=name, **pyvista_kwargs)
-        if not scalar_bar:
+        if not show_scalar_bar:
             self.remove_scalar_bar(geological_feature.name)
         return actor
 
@@ -263,7 +264,7 @@ class Loop3DView(pv.Plotter):
         cmap=None,
         model=None,
         pyvista_kwargs={},
-        scalar_bar: bool = False,
+        show_scalar_bar: bool = False,
         slicer: bool = False,
         threshold: Optional[Union[float, List[float]]] = None,
         name: Optional[str] = None,
@@ -282,7 +283,7 @@ class Loop3DView(pv.Plotter):
             the model to pass if it is not the active geologicalmodel, by default None
         pyvista_kwargs : dict, optional
             additional arguments to be passed to pyvista add_mesh, by default {}
-        scalar_bar : bool, optional
+        show_scalar_bar : bool, optional
             whether show/hide the scalar bar, by default False
         slicer : bool, optional
             If an interactive plane slicing tool should be added, by default False
@@ -311,7 +312,7 @@ class Loop3DView(pv.Plotter):
         else:
             actor = self.add_mesh(block, cmap=cmap, name=name, **pyvista_kwargs)
 
-        if not scalar_bar:
+        if not show_scalar_bar:
             self.remove_scalar_bar('stratigraphy')
         return actor
 
@@ -322,7 +323,7 @@ class Loop3DView(pv.Plotter):
         model=None,
         cmap="rainbow",
         pyvista_kwargs={},
-        scalar_bar: bool = False,
+        show_scalar_bar: bool = False,
         name: Optional[str] = None,
     ):
         """Plot the dispalcement magnitude for faults in the model
@@ -340,7 +341,7 @@ class Loop3DView(pv.Plotter):
             _description_, by default "rainbow"
         pyvista_kwargs : dict, optional
             _description_, by default {}
-        scalar_bar : bool, optional
+        show_scalar_bar : bool, optional
             _description_, by default False
         """
         if name is None:
@@ -360,7 +361,7 @@ class Loop3DView(pv.Plotter):
         volume = bounding_box.vtk()
         volume['displacement'] = displacement_value
         actor = self.add_mesh(volume, cmap=cmap, **pyvista_kwargs)
-        if not scalar_bar:
+        if not show_scalar_bar:
             self.remove_scalar_bar('displacement')
         return actor
 
@@ -399,7 +400,7 @@ class Loop3DView(pv.Plotter):
         model: Optional[GeologicalModel] = None,
         fault_colour: str = "black",
         pyvista_kwargs: dict = {},
-        scalar_bar: bool = False,
+        show_scalar_bar: bool = False,
         name: Optional[str] = None,
     ):
         """Plot the surfaces of the model
@@ -418,7 +419,7 @@ class Loop3DView(pv.Plotter):
             colour for the fault surfaces, by default "black"
         pyvista_kwargs : dict, optional
             Additional kwargs to send to add_mesh, by default {}
-        scalar_bar : bool, optional
+        show_scalar_bar : bool, optional
             whether to add the scalar bar, by default False
         name : Optional[str], optional
             name to add objects to object list with, by default None
@@ -451,7 +452,7 @@ class Loop3DView(pv.Plotter):
                     **pyvista_kwargs,
                 )
             )
-            if not scalar_bar:
+            if not show_scalar_bar:
                 self.remove_scalar_bar()
         if faults:
             fault_list = model.get_fault_surfaces()
@@ -476,6 +477,7 @@ class Loop3DView(pv.Plotter):
         normalise: bool = False,
         scale_function: Optional[Callable[[np.ndarray], np.ndarray]] = None,
         pyvista_kwargs: dict = {},
+        bounding_box: Optional[BoundingBox] = None,
     ) -> pv.Actor:
         """Plot a vector field
 
@@ -498,8 +500,9 @@ class Loop3DView(pv.Plotter):
         if name is None:
             name = geological_feature.name + '_vector_field'
         name = self.increment_name(name)  # , 'vector_field')
-        vectorfield = geological_feature.vector_field()
+        vectorfield = geological_feature.vector_field(bounding_box=bounding_box)
         scale = self._get_vector_scale(scale)
+        print(scale)
         return self.add_mesh(
             vectorfield.vtk(
                 scale=scale,
@@ -615,6 +618,7 @@ class Loop3DView(pv.Plotter):
         name: Optional[str] = None,
         geom: str = "arrow",
         pyvista_kwargs: dict = {},
+        bounding_box: Optional[BoundingBox] = None,
     ) -> List[pv.Actor]:
         """Plot a fault including the surface, slip vector and displacement volume
 
@@ -649,7 +653,7 @@ class Loop3DView(pv.Plotter):
             else:
                 surface_name = f'{fault.name}_surface_{name}'
             surface_name = self.increment_name(surface_name)
-            surf = fault.surfaces([0])[0]
+            surf = fault.surfaces([0], bounding_box=bounding_box)[0]
             actors.append(self.add_mesh(surf.vtk(), name=surface_name, **pyvista_kwargs))
         if slip_vector:
             if name is None:
@@ -658,7 +662,7 @@ class Loop3DView(pv.Plotter):
                 vector_name = f'{fault.name}_vector_{name}'
             vector_name = self.increment_name(vector_name)
 
-            vectorfield = fault.vector_field()
+            vectorfield = fault.vector_field(bounding_box=bounding_box)
             vector_scale = self._get_vector_scale(vector_scale)
             actors.append(
                 self.add_mesh(
@@ -672,7 +676,9 @@ class Loop3DView(pv.Plotter):
                 volume_name = fault.name + '_volume'
             else:
                 volume_name = f'{fault.name}_volume_{name}'
-            volume = fault.displacementfeature.scalar_field()
+
+            volume = fault.displacementfeature.scalar_field(bounding_box=bounding_box)
+
             volume = volume.vtk().threshold([-1.0, 1.0])
             if geom == "arrow":
                 geom = pv.Arrow()
@@ -709,7 +715,7 @@ class Loop3DView(pv.Plotter):
             name = fault.name + '_ellipsoid'
         name = self.increment_name(name)
         ellipsoid = fault.fault_ellipsoid()
-        return self.add_mesh(ellipsoid.vtk(), name=name, **pyvista_kwargs)
+        return self.add_mesh(ellipsoid, name=name, **pyvista_kwargs)
 
     def rotate(self, angles: np.ndarray):
         """Rotate the camera by the given angles
